@@ -1,708 +1,698 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ar">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
 <context>
     <name>AccountItem</name>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Network error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Server exception</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Storage full</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>AccountManager</name>
     <message>
         <source>Local account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CColorPickerWidget</name>
     <message>
         <source>Color</source>
-        <translation>لون</translation>
+        <translation type="vanished">لون</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>إلغاء</translation>
+        <translation type="vanished">إلغاء</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>حفظ</translation>
+        <translation type="vanished">حفظ</translation>
     </message>
 </context>
 <context>
     <name>CDayMonthView</name>
     <message>
         <source>Monday</source>
-        <translation>الاثنين</translation>
+        <translation type="vanished">الاثنين</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation>الثلاثاء</translation>
+        <translation type="vanished">الثلاثاء</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation>الأربعاء</translation>
+        <translation type="vanished">الأربعاء</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation>الخميس</translation>
+        <translation type="vanished">الخميس</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation>الجمعة</translation>
+        <translation type="vanished">الجمعة</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation>السبت</translation>
+        <translation type="vanished">السبت</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>الأحد</translation>
+        <translation type="vanished">الأحد</translation>
     </message>
 </context>
 <context>
     <name>CDayWindow</name>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>الشهر</translation>
+        <translation type="vanished">الشهر</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>اليوم</translation>
+        <translation type="vanished">اليوم</translation>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CGraphicsView</name>
     <message>
         <source>New Event</source>
-        <translation>حدث جديد</translation>
+        <translation type="vanished">حدث جديد</translation>
     </message>
 </context>
 <context>
     <name>CMonthScheduleNumItem</name>
     <message>
         <source>%1 more</source>
-        <translation>1% أكثر</translation>
+        <translation type="vanished">1% أكثر</translation>
     </message>
 </context>
 <context>
     <name>CMonthView</name>
     <message>
         <source>New event</source>
-        <translation>حدث جديد</translation>
+        <translation type="vanished">حدث جديد</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>حدث جديد</translation>
+        <translation type="vanished">حدث جديد</translation>
     </message>
 </context>
 <context>
     <name>CMonthWindow</name>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
 </context>
 <context>
     <name>CMyScheduleView</name>
     <message>
         <source>My Event</source>
-        <translation>الحدث الخاص بي</translation>
+        <translation type="vanished">الحدث الخاص بي</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>موافق</translation>
+        <translation type="vanished">موافق</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
     <message>
         <source>Edit</source>
         <comment>button</comment>
-        <translation>تحرير</translation>
+        <translation type="vanished">تحرير</translation>
     </message>
 </context>
 <context>
     <name>CPushButton</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CScheduleDlg</name>
     <message>
         <source>New Event</source>
-        <translation>لا أحداث</translation>
+        <translation type="vanished">لا أحداث</translation>
     </message>
     <message>
         <source>Edit Event</source>
-        <translation>تعديل الأحداث</translation>
+        <translation type="vanished">تعديل الأحداث</translation>
     </message>
     <message>
         <source>End time must be greater than start time</source>
-        <translation>يجب أن يكون وقت الانتهاء أكبر من وقت البدء</translation>
+        <translation type="vanished">يجب أن يكون وقت الانتهاء أكبر من وقت البدء</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>حسنا</translation>
+        <translation type="vanished">حسنا</translation>
     </message>
     <message>
         <source>Never</source>
-        <translation>أبدا</translation>
+        <translation type="vanished">أبدا</translation>
     </message>
     <message>
         <source>At time of event</source>
-        <translation>في وقت الحدث</translation>
+        <translation type="vanished">في وقت الحدث</translation>
     </message>
     <message>
         <source>15 minutes before</source>
-        <translation>15 دقيقة قبل</translation>
+        <translation type="vanished">15 دقيقة قبل</translation>
     </message>
     <message>
         <source>30 minutes before</source>
-        <translation>30 دقيقة قبل</translation>
+        <translation type="vanished">30 دقيقة قبل</translation>
     </message>
     <message>
         <source>1 hour before</source>
-        <translation>1 ساعة قبل</translation>
+        <translation type="vanished">1 ساعة قبل</translation>
     </message>
     <message>
         <source>1 day before</source>
-        <translation>1 يوم قبل</translation>
+        <translation type="vanished">1 يوم قبل</translation>
     </message>
     <message>
         <source>2 days before</source>
-        <translation> “2“يومين قبل</translation>
+        <translation type="vanished"> “2“يومين قبل</translation>
     </message>
     <message>
         <source>1 week before</source>
-        <translation>1 أسبوع قبل</translation>
+        <translation type="vanished">1 أسبوع قبل</translation>
     </message>
     <message>
         <source>On start day (9:00 AM)</source>
-        <translation>في يوم البَدْء (9:00 صباحا)</translation>
+        <translation type="vanished">في يوم البَدْء (9:00 صباحا)</translation>
     </message>
     <message>
         <source>time(s)</source>
-        <translation>الوقت(ج)</translation>
+        <translation type="vanished">الوقت(ج)</translation>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Type:</source>
-        <translation>النوع:</translation>
+        <translation type="vanished">النوع:</translation>
     </message>
     <message>
         <source>Description:</source>
-        <translation>الوصف:</translation>
+        <translation type="vanished">الوصف:</translation>
     </message>
     <message>
         <source>All Day:</source>
-        <translation>طوال اليوم:</translation>
+        <translation type="vanished">طوال اليوم:</translation>
     </message>
     <message>
         <source>Starts:</source>
-        <translation>يبدأ:</translation>
+        <translation type="vanished">يبدأ:</translation>
     </message>
     <message>
         <source>Ends:</source>
-        <translation>ينتهي:</translation>
+        <translation type="vanished">ينتهي:</translation>
     </message>
     <message>
         <source>Remind Me:</source>
-        <translation>ذكرني:</translation>
+        <translation type="vanished">ذكرني:</translation>
     </message>
     <message>
         <source>Repeat:</source>
-        <translation>تكرار</translation>
+        <translation type="vanished">تكرار</translation>
     </message>
     <message>
         <source>End Repeat:</source>
-        <translation>نهاية التكرار</translation>
+        <translation type="vanished">نهاية التكرار</translation>
     </message>
     <message>
         <source>Calendar account:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Type</source>
-        <translation>النوع</translation>
+        <translation type="vanished">النوع</translation>
     </message>
     <message>
         <source>Description</source>
-        <translation>الوصف</translation>
+        <translation type="vanished">الوصف</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>طوال اليوم</translation>
+        <translation type="vanished">طوال اليوم</translation>
     </message>
     <message>
         <source>Time:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Solar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Starts</source>
-        <translation>يبدأ</translation>
+        <translation type="vanished">يبدأ</translation>
     </message>
     <message>
         <source>Ends</source>
-        <translation>ينتهي</translation>
+        <translation type="vanished">ينتهي</translation>
     </message>
     <message>
         <source>Remind Me</source>
-        <translation>ذكرني</translation>
+        <translation type="vanished">ذكرني</translation>
     </message>
     <message>
         <source>Repeat</source>
-        <translation>تكرار</translation>
+        <translation type="vanished">تكرار</translation>
     </message>
     <message>
         <source>Daily</source>
-        <translation>يوميا</translation>
+        <translation type="vanished">يوميا</translation>
     </message>
     <message>
         <source>Weekdays</source>
-        <translation>أيام الأسبوع</translation>
+        <translation type="vanished">أيام الأسبوع</translation>
     </message>
     <message>
         <source>Weekly</source>
-        <translation>أسبوعيا</translation>
+        <translation type="vanished">أسبوعيا</translation>
     </message>
     <message>
         <source>Monthly</source>
-        <translation>شهريا</translation>
+        <translation type="vanished">شهريا</translation>
     </message>
     <message>
         <source>Yearly</source>
-        <translation>سنويا</translation>
+        <translation type="vanished">سنويا</translation>
     </message>
     <message>
         <source>End Repeat</source>
-        <translation>نهاية التكرار</translation>
+        <translation type="vanished">نهاية التكرار</translation>
     </message>
     <message>
         <source>After</source>
-        <translation>بعد</translation>
+        <translation type="vanished">بعد</translation>
     </message>
     <message>
         <source>On</source>
-        <translation>تشغيل</translation>
+        <translation type="vanished">تشغيل</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>إلغاء</translation>
+        <translation type="vanished">إلغاء</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>حفظ</translation>
+        <translation type="vanished">حفظ</translation>
     </message>
 </context>
 <context>
     <name>CScheduleOperation</name>
     <message>
         <source>All occurrences of a repeating event must have the same all-day status.</source>
-        <translation>يجب أن يكون لجميع حالات تكرار الحدث نفس الوضع طوال اليوم.</translation>
+        <translation type="vanished">يجب أن يكون لجميع حالات تكرار الحدث نفس الوضع طوال اليوم.</translation>
     </message>
     <message>
         <source>Do you want to change all occurrences?</source>
-        <translation>هل تريد تغيير كل الأحداث؟</translation>
+        <translation type="vanished">هل تريد تغيير كل الأحداث؟</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>إلغاء</translation>
+        <translation type="vanished">إلغاء</translation>
     </message>
     <message>
         <source>Change All</source>
-        <translation>تغيير الكل</translation>
+        <translation type="vanished">تغيير الكل</translation>
     </message>
     <message>
         <source>You are changing the repeating rule of this event.</source>
-        <translation>أنت تغير قاعدة التكرار لهذا الحدث.</translation>
+        <translation type="vanished">أنت تغير قاعدة التكرار لهذا الحدث.</translation>
     </message>
     <message>
         <source>You are deleting an event.</source>
-        <translation>أنت تقوم بحذف حدث.</translation>
+        <translation type="vanished">أنت تقوم بحذف حدث.</translation>
     </message>
     <message>
         <source>Are you sure you want to delete this event?</source>
-        <translation>هل أنت متأكد من أنك تريد حذف هذا الحدث؟</translation>
+        <translation type="vanished">هل أنت متأكد من أنك تريد حذف هذا الحدث؟</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
     <message>
         <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
-        <translation>هل تريد حذف جميع حالات هذا الحدث، أو فقط الأحداث المحددة؟</translation>
+        <translation type="vanished">هل تريد حذف جميع حالات هذا الحدث، أو فقط الأحداث المحددة؟</translation>
     </message>
     <message>
         <source>Delete All</source>
-        <translation>حذف الكل</translation>
+        <translation type="vanished">حذف الكل</translation>
     </message>
     <message>
         <source>Delete Only This Event</source>
-        <translation>حذف هذا الحدث فقط</translation>
+        <translation type="vanished">حذف هذا الحدث فقط</translation>
     </message>
     <message>
         <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
-        <translation>هل تريد حذف هذا وجميع الحالات المستقبلية لهذا الحدث، أو فقط الأحداث المحددة؟</translation>
+        <translation type="vanished">هل تريد حذف هذا وجميع الحالات المستقبلية لهذا الحدث، أو فقط الأحداث المحددة؟</translation>
     </message>
     <message>
         <source>Delete All Future Events</source>
-        <translation>حذف جميع الأحداث المستقبلية</translation>
+        <translation type="vanished">حذف جميع الأحداث المستقبلية</translation>
     </message>
     <message>
         <source>You are changing a repeating event.</source>
-        <translation>أنت تقوم بتغيير حدث متكرر.</translation>
+        <translation type="vanished">أنت تقوم بتغيير حدث متكرر.</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
-        <translation>هل تريد تغيير هذا الحدث فقط، أو كل الأحداث؟</translation>
+        <translation type="vanished">هل تريد تغيير هذا الحدث فقط، أو كل الأحداث؟</translation>
     </message>
     <message>
         <source>All</source>
-        <translation>الجميع</translation>
+        <translation type="vanished">الجميع</translation>
     </message>
     <message>
         <source>Only This Event</source>
-        <translation>هذا الحدث فقط</translation>
+        <translation type="vanished">هذا الحدث فقط</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
-        <translation>هل تريد تغيير هذا الحدث فقط، أو هذا وكل الأحداث المستقبلية؟</translation>
+        <translation type="vanished">هل تريد تغيير هذا الحدث فقط، أو هذا وكل الأحداث المستقبلية؟</translation>
     </message>
     <message>
         <source>All Future Events</source>
-        <translation>كل الأحداث المستقبلية</translation>
+        <translation type="vanished">كل الأحداث المستقبلية</translation>
     </message>
     <message>
         <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>موافق</translation>
+        <translation type="vanished">موافق</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchDateItem</name>
     <message>
         <source>Y</source>
-        <translation>سنة</translation>
+        <translation type="vanished">سنة</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>شهر</translation>
+        <translation type="vanished">شهر</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>يوم</translation>
+        <translation type="vanished">يوم</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchItem</name>
     <message>
         <source>Edit</source>
-        <translation>تعديل</translation>
+        <translation type="vanished">تعديل</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>طوال اليوم</translation>
+        <translation type="vanished">طوال اليوم</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchView</name>
     <message>
         <source>No search results</source>
-        <translation>لا توجد نتائج بحث</translation>
+        <translation type="vanished">لا توجد نتائج بحث</translation>
     </message>
 </context>
 <context>
     <name>CScheduleView</name>
     <message>
         <source>ALL DAY</source>
-        <translation>طوال اليوم</translation>
+        <translation type="vanished">طوال اليوم</translation>
     </message>
 </context>
 <context>
     <name>CSettingDialog</name>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Manual</source>
-        <translation>يدوي</translation>
+        <translation type="vanished">يدوي</translation>
     </message>
     <message>
         <source>15 mins</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>30 mins</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>1 hour</source>
-        <translation>1 ساعة</translation>
+        <translation type="vanished">1 ساعة</translation>
     </message>
     <message>
         <source>24 hours</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync Now</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Last sync</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Monday</source>
-        <translation>الاثنين</translation>
-    </message>
-    <message>
-        <source>Tuesday</source>
-        <translation type="unfinished">الثلاثاء</translation>
-    </message>
-    <message>
-        <source>Wednesday</source>
-        <translation type="unfinished">الأربعاء</translation>
-    </message>
-    <message>
-        <source>Thursday</source>
-        <translation type="unfinished">الخميس</translation>
-    </message>
-    <message>
-        <source>Friday</source>
-        <translation type="unfinished">الجمعة</translation>
-    </message>
-    <message>
-        <source>Saturday</source>
-        <translation type="unfinished">السبت</translation>
+        <translation type="vanished">الاثنين</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>الأحد</translation>
+        <translation type="vanished">الأحد</translation>
     </message>
     <message>
         <source>12-hour clock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>24-hour clock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Please go to the &lt;a href=&apos;/&apos;&gt;Control Center&lt;/a&gt; to change settings</source>
-        <translation type="unfinished"></translation>
+        <source>Tuesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CTimeEdit</name>
     <message>
         <source>(%1 mins)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>(%1 hour)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>(%1 hours)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CTitleWidget</name>
     <message>
         <source>Y</source>
-        <translation>سنة</translation>
+        <translation type="vanished">سنة</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>شهر</translation>
+        <translation type="vanished">شهر</translation>
     </message>
     <message>
         <source>W</source>
-        <translation>أسبوع</translation>
+        <translation type="vanished">أسبوع</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>يوم</translation>
+        <translation type="vanished">يوم</translation>
     </message>
     <message>
         <source>Search events and festivals</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CWeekWidget</name>
     <message>
         <source>Sun</source>
-        <translation>الأحد</translation>
+        <translation type="vanished">الأحد</translation>
     </message>
     <message>
         <source>Mon</source>
-        <translation>الاثنين</translation>
+        <translation type="vanished">الاثنين</translation>
     </message>
     <message>
         <source>Tue</source>
-        <translation>الثلاثاء</translation>
+        <translation type="vanished">الثلاثاء</translation>
     </message>
     <message>
         <source>Wed</source>
-        <translation>الأربعاء</translation>
+        <translation type="vanished">الأربعاء</translation>
     </message>
     <message>
         <source>Thu</source>
-        <translation>الخميس</translation>
+        <translation type="vanished">الخميس</translation>
     </message>
     <message>
         <source>Fri</source>
-        <translation>الجمعة</translation>
+        <translation type="vanished">الجمعة</translation>
     </message>
     <message>
         <source>Sat</source>
-        <translation>السبت</translation>
+        <translation type="vanished">السبت</translation>
     </message>
 </context>
 <context>
     <name>CWeekWindow</name>
     <message>
         <source>Week</source>
-        <translation>الأسبوع</translation>
+        <translation type="vanished">الأسبوع</translation>
     </message>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
 </context>
 <context>
     <name>CYearScheduleView</name>
     <message>
         <source>All Day</source>
-        <translation>طوال اليوم</translation>
+        <translation type="vanished">طوال اليوم</translation>
     </message>
     <message>
         <source>No event</source>
-        <translation>لا يوجد حدث</translation>
+        <translation type="vanished">لا يوجد حدث</translation>
     </message>
 </context>
 <context>
     <name>CYearWindow</name>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
 </context>
 <context>
     <name>CalendarWindow</name>
     <message>
         <source>Calendar</source>
-        <translation>التقويم</translation>
+        <translation type="vanished">التقويم</translation>
     </message>
     <message>
         <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
-        <translation>التقويم هو برنامج لعرض التواريخ وللتخطيط الذكي لجميع الأشياء في الحياة</translation>
+        <translation type="vanished">التقويم هو برنامج لعرض التواريخ وللتخطيط الذكي لجميع الأشياء في الحياة</translation>
     </message>
 </context>
 <context>
     <name>Calendarmainwindow</name>
     <message>
         <source>Calendar</source>
-        <translation>التقويم</translation>
+        <translation type="vanished">التقويم</translation>
     </message>
     <message>
         <source>Manage</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Syncing...</source>
-        <translation>جاري المزامنة...</translation>
+        <translation type="vanished">جاري المزامنة...</translation>
     </message>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync failed, please try later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CenterWidget</name>
     <message>
         <source>All Day</source>
-        <translation>طوال اليوم</translation>
+        <translation type="vanished">طوال اليوم</translation>
     </message>
 </context>
 <context>
@@ -741,15 +731,15 @@
     </message>
     <message>
         <source>15 mins later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>1 hour later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>4 hours later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Tomorrow</source>
@@ -761,7 +751,7 @@
     </message>
     <message>
         <source>%1 to %2</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Today</source>
@@ -772,99 +762,91 @@
     <name>DragInfoGraphicsView</name>
     <message>
         <source>Edit</source>
-        <translation>تحرير</translation>
+        <translation type="vanished">تحرير</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
     <message>
         <source>New event</source>
-        <translation>حدث جديد</translation>
+        <translation type="vanished">حدث جديد</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>حدث جديد</translation>
+        <translation type="vanished">حدث جديد</translation>
     </message>
 </context>
 <context>
     <name>JobTypeListView</name>
-    <message>
-        <source>export</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>You are deleting an event type.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>All events under this type will be deleted and cannot be recovered.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>إلغاء</translation>
+        <translation type="vanished">إلغاء</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Account settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Account</source>
-        <translation>حساب</translation>
+        <translation type="vanished">حساب</translation>
     </message>
     <message>
         <source>Select items to be synced</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Events</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>General settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync interval</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Manage calendar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>General</source>
-        <translation>عام</translation>
+        <translation type="vanished">عام</translation>
     </message>
     <message>
         <source>First day of week</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -872,7 +854,7 @@
     <message>
         <source>Today</source>
         <comment>Return</comment>
-        <translation>اليوم</translation>
+        <translation type="vanished">اليوم</translation>
     </message>
 </context>
 <context>
@@ -880,94 +862,86 @@
     <message>
         <source>Today</source>
         <comment>Return Today</comment>
-        <translation>اليوم</translation>
+        <translation type="vanished">اليوم</translation>
     </message>
 </context>
 <context>
     <name>ScheduleTypeEditDlg</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Edit event type</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Import ICS file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Name:</source>
-        <translation>الاسم :</translation>
+        <translation type="vanished">الاسم :</translation>
     </message>
     <message>
         <source>Color:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>إلغاء</translation>
+        <translation type="vanished">إلغاء</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>حفظ</translation>
+        <translation type="vanished">حفظ</translation>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>Shortcut</name>
     <message>
         <source>Help</source>
-        <translation>مساعدة</translation>
+        <translation type="vanished">مساعدة</translation>
     </message>
     <message>
         <source>Delete event</source>
-        <translation>حذف حدث</translation>
+        <translation type="vanished">حذف حدث</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation>نسخ</translation>
+        <translation type="vanished">نسخ</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation>قص</translation>
+        <translation type="vanished">قص</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation>لصق</translation>
+        <translation type="vanished">لصق</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>حذف</translation>
+        <translation type="vanished">حذف</translation>
     </message>
     <message>
         <source>Select all</source>
-        <translation>تحديد الكل</translation>
+        <translation type="vanished">تحديد الكل</translation>
     </message>
 </context>
 <context>
     <name>SidebarCalendarWidget</name>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>الشهر</translation>
+        <translation type="vanished">الشهر</translation>
     </message>
 </context>
 <context>
@@ -975,7 +949,7 @@
     <message>
         <source>Go</source>
         <comment>button</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -983,19 +957,19 @@
     <message>
         <source>Sign In</source>
         <comment>button</comment>
-        <translation>تسجيل الدخول</translation>
+        <translation type="vanished">تسجيل الدخول</translation>
     </message>
     <message>
         <source>Sign Out</source>
         <comment>button</comment>
-        <translation>تسجيل الخروج</translation>
+        <translation type="vanished">تسجيل الخروج</translation>
     </message>
 </context>
 <context>
     <name>YearFrame</name>
     <message>
         <source>Y</source>
-        <translation>السنة</translation>
+        <translation type="vanished">السنة</translation>
     </message>
 </context>
 <context>
@@ -1003,7 +977,7 @@
     <message>
         <source>Today</source>
         <comment>Today</comment>
-        <translation>اليوم</translation>
+        <translation type="vanished">اليوم</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
