@@ -1,708 +1,698 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="ka">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ka">
 <context>
     <name>AccountItem</name>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Network error</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Server exception</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Storage full</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>AccountManager</name>
     <message>
         <source>Local account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CColorPickerWidget</name>
     <message>
         <source>Color</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>გაუქმება</translation>
+        <translation type="vanished">გაუქმება</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>შენახვა</translation>
+        <translation type="vanished">შენახვა</translation>
     </message>
 </context>
 <context>
     <name>CDayMonthView</name>
     <message>
         <source>Monday</source>
-        <translation>ორშაბათი</translation>
+        <translation type="vanished">ორშაბათი</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation>სამშაბათი</translation>
+        <translation type="vanished">სამშაბათი</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation>ოთხშაბათი</translation>
+        <translation type="vanished">ოთხშაბათი</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation>ხუთშაბათი</translation>
+        <translation type="vanished">ხუთშაბათი</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation>პარასკევი</translation>
+        <translation type="vanished">პარასკევი</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation>შაბათი</translation>
+        <translation type="vanished">შაბათი</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>კვირა</translation>
+        <translation type="vanished">კვირა</translation>
     </message>
 </context>
 <context>
     <name>CDayWindow</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>თ</translation>
+        <translation type="vanished">თ</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>დ</translation>
+        <translation type="vanished">დ</translation>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CGraphicsView</name>
     <message>
         <source>New Event</source>
-        <translation>ახალი ივენთი</translation>
+        <translation type="vanished">ახალი ივენთი</translation>
     </message>
 </context>
 <context>
     <name>CMonthScheduleNumItem</name>
     <message>
         <source>%1 more</source>
-        <translation>%1 მეტი</translation>
+        <translation type="vanished">%1 მეტი</translation>
     </message>
 </context>
 <context>
     <name>CMonthView</name>
     <message>
         <source>New event</source>
-        <translation>ახალი ივენთი</translation>
+        <translation type="vanished">ახალი ივენთი</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>ახალი ივენთი</translation>
+        <translation type="vanished">ახალი ივენთი</translation>
     </message>
 </context>
 <context>
     <name>CMonthWindow</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
 </context>
 <context>
     <name>CMyScheduleView</name>
     <message>
         <source>My Event</source>
-        <translation>ჩემი ივენთები</translation>
+        <translation type="vanished">ჩემი ივენთები</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>OK</translation>
+        <translation type="vanished">OK</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
     <message>
         <source>Edit</source>
         <comment>button</comment>
-        <translation>რედაქტირება</translation>
+        <translation type="vanished">რედაქტირება</translation>
     </message>
 </context>
 <context>
     <name>CPushButton</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CScheduleDlg</name>
     <message>
         <source>New Event</source>
-        <translation>ჩემი ივენთები</translation>
+        <translation type="vanished">ჩემი ივენთები</translation>
     </message>
     <message>
         <source>Edit Event</source>
-        <translation>ივენთის რედაქტირება</translation>
+        <translation type="vanished">ივენთის რედაქტირება</translation>
     </message>
     <message>
         <source>End time must be greater than start time</source>
-        <translation>დასრულების დრო უნდა აღემატებოდეს დაწყების დროს</translation>
+        <translation type="vanished">დასრულების დრო უნდა აღემატებოდეს დაწყების დროს</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>OK</translation>
+        <translation type="vanished">OK</translation>
     </message>
     <message>
         <source>Never</source>
-        <translation>არასდროს</translation>
+        <translation type="vanished">არასდროს</translation>
     </message>
     <message>
         <source>At time of event</source>
-        <translation>ივენთის სრული დრო</translation>
+        <translation type="vanished">ივენთის სრული დრო</translation>
     </message>
     <message>
         <source>15 minutes before</source>
-        <translation>15 წუთით ადრე</translation>
+        <translation type="vanished">15 წუთით ადრე</translation>
     </message>
     <message>
         <source>30 minutes before</source>
-        <translation>30 წუთით ადრე</translation>
+        <translation type="vanished">30 წუთით ადრე</translation>
     </message>
     <message>
         <source>1 hour before</source>
-        <translation>1 საათით ადრე</translation>
+        <translation type="vanished">1 საათით ადრე</translation>
     </message>
     <message>
         <source>1 day before</source>
-        <translation>1 დღით ადრე</translation>
+        <translation type="vanished">1 დღით ადრე</translation>
     </message>
     <message>
         <source>2 days before</source>
-        <translation>2 დღით ადრე</translation>
+        <translation type="vanished">2 დღით ადრე</translation>
     </message>
     <message>
         <source>1 week before</source>
-        <translation>1 კვირით ადრე</translation>
+        <translation type="vanished">1 კვირით ადრე</translation>
     </message>
     <message>
         <source>On start day (9:00 AM)</source>
-        <translation>დრის დასაწყისში (9:00 AM)</translation>
+        <translation type="vanished">დრის დასაწყისში (9:00 AM)</translation>
     </message>
     <message>
         <source>time(s)</source>
-        <translation>ჯერ</translation>
+        <translation type="vanished">ჯერ</translation>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Type:</source>
-        <translation>ტიპი: </translation>
+        <translation type="vanished">ტიპი: </translation>
     </message>
     <message>
         <source>Description:</source>
-        <translation>აღწერა: </translation>
+        <translation type="vanished">აღწერა: </translation>
     </message>
     <message>
         <source>All Day:</source>
-        <translation>მთელი დღე: </translation>
+        <translation type="vanished">მთელი დღე: </translation>
     </message>
     <message>
         <source>Starts:</source>
-        <translation>დასაწყისი: </translation>
+        <translation type="vanished">დასაწყისი: </translation>
     </message>
     <message>
         <source>Ends:</source>
-        <translation>დასასრული: </translation>
+        <translation type="vanished">დასასრული: </translation>
     </message>
     <message>
         <source>Remind Me:</source>
-        <translation>შემახსენე: </translation>
+        <translation type="vanished">შემახსენე: </translation>
     </message>
     <message>
         <source>Repeat:</source>
-        <translation>გამეორება: </translation>
+        <translation type="vanished">გამეორება: </translation>
     </message>
     <message>
         <source>End Repeat:</source>
-        <translation>გამეორების დასასრული: </translation>
+        <translation type="vanished">გამეორების დასასრული: </translation>
     </message>
     <message>
         <source>Calendar account:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Type</source>
-        <translation>ტიპი</translation>
+        <translation type="vanished">ტიპი</translation>
     </message>
     <message>
         <source>Description</source>
-        <translation>აღწერა</translation>
+        <translation type="vanished">აღწერა</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>ყველა დღე</translation>
+        <translation type="vanished">ყველა დღე</translation>
     </message>
     <message>
         <source>Time:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Solar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Starts</source>
-        <translation>დასაწყისი</translation>
+        <translation type="vanished">დასაწყისი</translation>
     </message>
     <message>
         <source>Ends</source>
-        <translation>დასასრული</translation>
+        <translation type="vanished">დასასრული</translation>
     </message>
     <message>
         <source>Remind Me</source>
-        <translation>შემახსენე</translation>
+        <translation type="vanished">შემახსენე</translation>
     </message>
     <message>
         <source>Repeat</source>
-        <translation>განმეორება</translation>
+        <translation type="vanished">განმეორება</translation>
     </message>
     <message>
         <source>Daily</source>
-        <translation>დღიური</translation>
+        <translation type="vanished">დღიური</translation>
     </message>
     <message>
         <source>Weekdays</source>
-        <translation>ვიქენდი</translation>
+        <translation type="vanished">ვიქენდი</translation>
     </message>
     <message>
         <source>Weekly</source>
-        <translation>კვირეული</translation>
+        <translation type="vanished">კვირეული</translation>
     </message>
     <message>
         <source>Monthly</source>
-        <translation>თვიური</translation>
+        <translation type="vanished">თვიური</translation>
     </message>
     <message>
         <source>Yearly</source>
-        <translation>წლიური</translation>
+        <translation type="vanished">წლიური</translation>
     </message>
     <message>
         <source>End Repeat</source>
-        <translation>განმეორების დასასრული</translation>
+        <translation type="vanished">განმეორების დასასრული</translation>
     </message>
     <message>
         <source>After</source>
-        <translation>შემდეგ</translation>
+        <translation type="vanished">შემდეგ</translation>
     </message>
     <message>
         <source>On</source>
-        <translation>ზე</translation>
+        <translation type="vanished">ზე</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>გაუქმება</translation>
+        <translation type="vanished">გაუქმება</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>შენახვა</translation>
+        <translation type="vanished">შენახვა</translation>
     </message>
 </context>
 <context>
     <name>CScheduleOperation</name>
     <message>
         <source>All occurrences of a repeating event must have the same all-day status.</source>
-        <translation>ყველა განმეორებად მოვლენებს უნდა ჰქონდეს ყველა დღის სტატუს</translation>
+        <translation type="vanished">ყველა განმეორებად მოვლენებს უნდა ჰქონდეს ყველა დღის სტატუს</translation>
     </message>
     <message>
         <source>Do you want to change all occurrences?</source>
-        <translation>გსურთი მოვლენების შეცვლა?</translation>
+        <translation type="vanished">გსურთი მოვლენების შეცვლა?</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>გაუქმება</translation>
+        <translation type="vanished">გაუქმება</translation>
     </message>
     <message>
         <source>Change All</source>
-        <translation>ყველას შეცვლა</translation>
+        <translation type="vanished">ყველას შეცვლა</translation>
     </message>
     <message>
         <source>You are changing the repeating rule of this event.</source>
-        <translation>თქვენ ცვლით განმეორების რულებს აღნიშნული ივენთისთვის</translation>
+        <translation type="vanished">თქვენ ცვლით განმეორების რულებს აღნიშნული ივენთისთვის</translation>
     </message>
     <message>
         <source>You are deleting an event.</source>
-        <translation>თქვენ შლით ივენთს</translation>
+        <translation type="vanished">თქვენ შლით ივენთს</translation>
     </message>
     <message>
         <source>Are you sure you want to delete this event?</source>
-        <translation>დაწრმუნებული ხართ, რომ გსურთ ამ ივენთის წაშლა?</translation>
+        <translation type="vanished">დაწრმუნებული ხართ, რომ გსურთ ამ ივენთის წაშლა?</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
     <message>
         <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
-        <translation>გსრუთ აღნიშნული მოვლენების ივენთიდან ამოშლა?</translation>
+        <translation type="vanished">გსრუთ აღნიშნული მოვლენების ივენთიდან ამოშლა?</translation>
     </message>
     <message>
         <source>Delete All</source>
-        <translation>ყველას წაშლა</translation>
+        <translation type="vanished">ყველას წაშლა</translation>
     </message>
     <message>
         <source>Delete Only This Event</source>
-        <translation>მხოლოდ ამ ივენთის წაშლა</translation>
+        <translation type="vanished">მხოლოდ ამ ივენთის წაშლა</translation>
     </message>
     <message>
         <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
-        <translation>გსურთ წაშალოთ ყველა შემდგომი მოვლენა, თუ მხოლოდ არჩეული მოვლენები?</translation>
+        <translation type="vanished">გსურთ წაშალოთ ყველა შემდგომი მოვლენა, თუ მხოლოდ არჩეული მოვლენები?</translation>
     </message>
     <message>
         <source>Delete All Future Events</source>
-        <translation>ყველა მომდევნო მოვლენის წაშლა</translation>
+        <translation type="vanished">ყველა მომდევნო მოვლენის წაშლა</translation>
     </message>
     <message>
         <source>You are changing a repeating event.</source>
-        <translation>თქვენ ცვლით განმეორებად ივენთს</translation>
+        <translation type="vanished">თქვენ ცვლით განმეორებად ივენთს</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
-        <translation>გსრუთ ყველა მოვლენის შეცვლა, თუ მხოლოდ მონიშნულის?</translation>
+        <translation type="vanished">გსრუთ ყველა მოვლენის შეცვლა, თუ მხოლოდ მონიშნულის?</translation>
     </message>
     <message>
         <source>All</source>
-        <translation>ყველა</translation>
+        <translation type="vanished">ყველა</translation>
     </message>
     <message>
         <source>Only This Event</source>
-        <translation>მხოლოდ ეს ივენთი</translation>
+        <translation type="vanished">მხოლოდ ეს ივენთი</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
-        <translation>მხოლოდ ამ ერთი მოვლენის შეცვლა, თუ ყველა მომდევნო მოვლენის შეცვლა?</translation>
+        <translation type="vanished">მხოლოდ ამ ერთი მოვლენის შეცვლა, თუ ყველა მომდევნო მოვლენის შეცვლა?</translation>
     </message>
     <message>
         <source>All Future Events</source>
-        <translation>ყველა მომდევნო ივენთი</translation>
+        <translation type="vanished">ყველა მომდევნო ივენთი</translation>
     </message>
     <message>
         <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>OK</translation>
+        <translation type="vanished">OK</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchDateItem</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>თ</translation>
+        <translation type="vanished">თ</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>დ</translation>
+        <translation type="vanished">დ</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchItem</name>
     <message>
         <source>Edit</source>
-        <translation>რედაქტირება</translation>
+        <translation type="vanished">რედაქტირება</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>ყველა დღე</translation>
+        <translation type="vanished">ყველა დღე</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchView</name>
     <message>
         <source>No search results</source>
-        <translation>არ არის ძებნის რეზულტატი</translation>
+        <translation type="vanished">არ არის ძებნის რეზულტატი</translation>
     </message>
 </context>
 <context>
     <name>CScheduleView</name>
     <message>
         <source>ALL DAY</source>
-        <translation>ყველა დღე</translation>
+        <translation type="vanished">ყველა დღე</translation>
     </message>
 </context>
 <context>
     <name>CSettingDialog</name>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Manual</source>
-        <translation>მექნიკურად</translation>
+        <translation type="vanished">მექნიკურად</translation>
     </message>
     <message>
         <source>15 mins</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>30 mins</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>1 hour</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>24 hours</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync Now</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Last sync</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Monday</source>
-        <translation>ორშაბათი</translation>
-    </message>
-    <message>
-        <source>Tuesday</source>
-        <translation type="unfinished">სამშაბათი</translation>
-    </message>
-    <message>
-        <source>Wednesday</source>
-        <translation type="unfinished">ოთხშაბათი</translation>
-    </message>
-    <message>
-        <source>Thursday</source>
-        <translation type="unfinished">ხუთშაბათი</translation>
-    </message>
-    <message>
-        <source>Friday</source>
-        <translation type="unfinished">პარასკევი</translation>
-    </message>
-    <message>
-        <source>Saturday</source>
-        <translation type="unfinished">შაბათი</translation>
+        <translation type="vanished">ორშაბათი</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>კვირა</translation>
+        <translation type="vanished">კვირა</translation>
     </message>
     <message>
         <source>12-hour clock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>24-hour clock</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
-        <source>Please go to the &lt;a href=&apos;/&apos;&gt;Control Center&lt;/a&gt; to change settings</source>
-        <translation type="unfinished"></translation>
+        <source>Tuesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CTimeEdit</name>
     <message>
         <source>(%1 mins)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>(%1 hour)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>(%1 hours)</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CTitleWidget</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>თ</translation>
+        <translation type="vanished">თ</translation>
     </message>
     <message>
         <source>W</source>
-        <translation>კ</translation>
+        <translation type="vanished">კ</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>დ</translation>
+        <translation type="vanished">დ</translation>
     </message>
     <message>
         <source>Search events and festivals</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CWeekWidget</name>
     <message>
         <source>Sun</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Mon</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Tue</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Wed</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Thu</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Fri</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sat</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CWeekWindow</name>
     <message>
         <source>Week</source>
-        <translation>კვირა</translation>
+        <translation type="vanished">კვირა</translation>
     </message>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
 </context>
 <context>
     <name>CYearScheduleView</name>
     <message>
         <source>All Day</source>
-        <translation>ყველა დღე</translation>
+        <translation type="vanished">ყველა დღე</translation>
     </message>
     <message>
         <source>No event</source>
-        <translation>არ არის ივენთი</translation>
+        <translation type="vanished">არ არის ივენთი</translation>
     </message>
 </context>
 <context>
     <name>CYearWindow</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
 </context>
 <context>
     <name>CalendarWindow</name>
     <message>
         <source>Calendar</source>
-        <translation>კალენდარი</translation>
+        <translation type="vanished">კალენდარი</translation>
     </message>
     <message>
         <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
-        <translation>კალენდარი არის ხელსაწყო თარიღების სანახავად და გრაფიკის დასაგეგმად</translation>
+        <translation type="vanished">კალენდარი არის ხელსაწყო თარიღების სანახავად და გრაფიკის დასაგეგმად</translation>
     </message>
 </context>
 <context>
     <name>Calendarmainwindow</name>
     <message>
         <source>Calendar</source>
-        <translation>კალენდარი</translation>
+        <translation type="vanished">კალენდარი</translation>
     </message>
     <message>
         <source>Manage</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Syncing...</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync failed, please try later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>CenterWidget</name>
     <message>
         <source>All Day</source>
-        <translation>ყველა დღე</translation>
+        <translation type="vanished">ყველა დღე</translation>
     </message>
 </context>
 <context>
@@ -741,15 +731,15 @@
     </message>
     <message>
         <source>15 mins later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>1 hour later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>4 hours later</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Tomorrow</source>
@@ -772,99 +762,91 @@
     <name>DragInfoGraphicsView</name>
     <message>
         <source>Edit</source>
-        <translation>რედაქტირება</translation>
+        <translation type="vanished">რედაქტირება</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
     <message>
         <source>New event</source>
-        <translation>ახალი ივენთი</translation>
+        <translation type="vanished">ახალი ივენთი</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>ახალი ივენთი</translation>
+        <translation type="vanished">ახალი ივენთი</translation>
     </message>
 </context>
 <context>
     <name>JobTypeListView</name>
-    <message>
-        <source>export</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>You are deleting an event type.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>All events under this type will be deleted and cannot be recovered.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>გაუქმება</translation>
+        <translation type="vanished">გაუქმება</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Account settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Select items to be synced</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Events</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>General settings</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sync interval</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Manage calendar</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>General</source>
-        <translation>ძირითადი</translation>
+        <translation type="vanished">ძირითადი</translation>
     </message>
     <message>
         <source>First day of week</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -872,7 +854,7 @@
     <message>
         <source>Today</source>
         <comment>Return</comment>
-        <translation>დღეს</translation>
+        <translation type="vanished">დღეს</translation>
     </message>
 </context>
 <context>
@@ -880,94 +862,86 @@
     <message>
         <source>Today</source>
         <comment>Return Today</comment>
-        <translation>დღეს</translation>
+        <translation type="vanished">დღეს</translation>
     </message>
 </context>
 <context>
     <name>ScheduleTypeEditDlg</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Edit event type</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Import ICS file</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Name:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Color:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>გაუქმება</translation>
+        <translation type="vanished">გაუქმება</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>შენახვა</translation>
+        <translation type="vanished">შენახვა</translation>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>Shortcut</name>
     <message>
         <source>Help</source>
-        <translation>დახმარება</translation>
+        <translation type="vanished">დახმარება</translation>
     </message>
     <message>
         <source>Delete event</source>
-        <translation>ივენთის წაშლა</translation>
+        <translation type="vanished">ივენთის წაშლა</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation>კოპირება</translation>
+        <translation type="vanished">კოპირება</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation>ამოჭრა</translation>
+        <translation type="vanished">ამოჭრა</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation>ჩასმა</translation>
+        <translation type="vanished">ჩასმა</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>წაშლა</translation>
+        <translation type="vanished">წაშლა</translation>
     </message>
     <message>
         <source>Select all</source>
-        <translation>ყველას მონიშნვა</translation>
+        <translation type="vanished">ყველას მონიშნვა</translation>
     </message>
 </context>
 <context>
     <name>SidebarCalendarWidget</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>თ</translation>
+        <translation type="vanished">თ</translation>
     </message>
 </context>
 <context>
@@ -975,7 +949,7 @@
     <message>
         <source>Go</source>
         <comment>button</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -983,19 +957,19 @@
     <message>
         <source>Sign In</source>
         <comment>button</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Sign Out</source>
         <comment>button</comment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
     <name>YearFrame</name>
     <message>
         <source>Y</source>
-        <translation>წ</translation>
+        <translation type="vanished">წ</translation>
     </message>
 </context>
 <context>
@@ -1003,7 +977,7 @@
     <message>
         <source>Today</source>
         <comment>Today</comment>
-        <translation>დღეს</translation>
+        <translation type="vanished">დღეს</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
